from django.conf.urls import include, url
from django.contrib import admin

urlpatterns = [
	url(r'^admin_tools/', include('admin_tools.urls')),
    url(r'^admin/', include(admin.site.urls)),
    url(r'', include('lists.urls', namespace='todos')),
]



from django import forms
from lists.models import Task
from django.contrib.admin import widgets


class TaskForm(forms.ModelForm):
	class Meta:
		model = Task
		fields = ['Title','Description', 'due_time']

	# def __init__(self, *args, **kwargs):
	# 	super(TaskForm, self).__init__(*args, **kwargs)
	# 	self.fields['due_time'].widget = widgets.AdminSplitDateTime()


from django.conf.urls import include, url
from django.contrib import admin

urlpatterns = [
    # url(r'$', 'lists.views.home_page'),
    url(r'^index/$', 'lists.views.index_page'),
    url(r'^$', 'lists.views.home_page'),
    url(r'^add-task/$', 'lists.views.add_task'),
    url(r'^edit-task/(?P<task_id>[0-9]+)/$', 'lists.views.edit_task'),
    url(r'^delete-task/(?P<task_id>[0-9]+)/$', 'lists.views.delete_task'),
    url(r'^task-list/$', 'lists.views.task_list'),
]
